@@ -9,6 +9,9 @@
 #' @param strike_action One of c("exclude", "keep", "star") or c("e", "k", "s"). Should stricken
 #'   values in the original .pzfx be excluded, kept or labeled with a trailing "*". If a trailing
 #'   "*" is added, the column will be of type character.
+#' @param date_x One of c("numeric", "character", "both") or c("n", "c", "b"). Should x column of
+#'   format "Date" be handled as numeric (time elapsed from the first time point), character (the date
+#'   string encoded by Prism, for example "8-Sep-2008"), or both (leading to two columns).
 #'
 #' @return a data frame
 #'
@@ -16,9 +19,13 @@
 #'
 #' @examples
 #' pzfx_file <- system.file("extdata/exponential_decay.pzfx", package = "pzfx", mustWork = TRUE)
-#' read_pzfx(pzfx_file, table = 1, strike_action="exclude")
-read_pzfx <- function(path, table=1, strike_action="exclude") {
+#' read_pzfx(pzfx_file, table = 1, strike_action="exclude", date_x="character")
+read_pzfx <- function(path, table=1, strike_action="exclude", date_x="character") {
   # sanity check
+  date_x <- tolower(date_x)
+  if (!date_x %in% c("numeric", "character", "both", "n", "c", "b")) {
+    stop("date_x must be one of c('numeric', 'character', 'both', 'n', 'c', 'b')")
+  }
   table_names <- pzfx::pzfx_tables(path)
   if (is.numeric(table)) {
     if (table > length(table_names)) stop("Table index out of range")
@@ -51,28 +58,46 @@ read_pzfx <- function(path, table=1, strike_action="exclude") {
   col_lst <- list()
   for (i in seq_len(length(this_table))) {
     if (names(this_table)[i] == "XColumn") {
-      this_col <- read_col(
-        this_table[[i]],
-        strike_action=strike_action,
-        col_name="X",
-        format=x_format)
+      # read in normally, unless it is date and we want character only
+      if (x_format == "date" &
+          (date_x %in% c("numeric", "n", "both", "b") |
+           !"XAdvancedColumn" %in% names(this_table))) {
+        this_col <- read_col(this_table[[i]], strike_action=strike_action, col_name="X", format="")
+        if (date_x %in% c("both", "b")) {
+          colnames(this_col) <- paste0(colnames(this_col), "_1")
+        }
+      } else if (x_format == "date") {
+        next
+      } else {
+        this_col <- read_col(this_table[[i]], strike_action=strike_action,
+                             col_name="X", format=x_format)
+      }
       if (nrow(this_col) > 0) {
         col_lst[[length(col_lst) + 1]] <- this_col
       }
+    } else if (names(this_table)[i] == "XAdvancedColumn") {
+      # do not read in unless it is date and we want character or both
+      if (x_format == "date" & date_x %in% c("character", "c", "both", "b")) {
+        this_col <- read_col(this_table[[i]], strike_action=strike_action, col_name="X", format="")
+        if (date_x %in% c("both", "b")) {
+          colnames(this_col) <- paste0(colnames(this_col), "_2")
+        }
+        if (nrow(this_col) > 0) {
+          col_lst[[length(col_lst) + 1]] <- this_col
+        }
+      } else {
+        next
+        # if in the future we find more XAdvancedColumn's that contain useful information
+        # they should be handled here
+      }
     } else if (names(this_table)[i] == "RowTitlesColumn") {
-      this_col <- read_col(
-        this_table[[i]],
-        strike_action=strike_action,
-        col_name="ROWTITLE",
-        format="")
+      this_col <- read_col(this_table[[i]], strike_action=strike_action,
+                           col_name="ROWTITLE", format="")
       if (nrow(this_col) > 0) {
         col_lst[[length(col_lst) + 1]] <- this_col
       }
     } else if (names(this_table)[i] == "YColumn") {
-      this_col <- read_col(
-        this_table[[i]],
-        strike_action=strike_action,
-        format=y_format)
+      this_col <- read_col(this_table[[i]], strike_action=strike_action, format=y_format)
       col_lst[[length(col_lst) + 1]] <- this_col
     }
   }
